@@ -60,10 +60,10 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 @report_loadsortemps @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns 
 @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns %vals 
 @sweeps @mediumiters @varinumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck retrieve
-$target %dowhat 
+$target %dowhat readsweeps 
 );
 
-$VERSION = '0.51.11'; # our $VERSION = '';
+$VERSION = '0.51.12'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -1019,7 +1019,7 @@ sub start
 ###########################################
 say "\nHi. This is Sim::OPT,
 a morphing and optimizazion program based on problem decomposition.
-Please insert the name of a configuration file for OPT (Unix path)\n";
+Please insert the name of a configuration file for OPT (Unix path):\n";
 ###########################################
 	$configfile = <STDIN>;
 	chomp $configfile;
@@ -1027,6 +1027,23 @@ Please insert the name of a configuration file for OPT (Unix path)\n";
 	else { &start; }
 }
 
+sub readsweeps
+{
+	my @struct = @_;
+	my @sourcestruct = @{ dclone( \@struct ) };
+	foreach ( @struct )
+	{
+		foreach ( @$_ )
+		{
+			if ( ( $_->[0] eq "s" ) or ( $_->[0] eq "p" ) )
+			{
+				shift( @$_ );
+			}
+		}
+	}
+	return ( \@struct, \@sourcestruct );
+}
+
 ###########################################################################################
 		
 sub opt
@@ -1117,7 +1134,15 @@ sub opt
 	{
 		#my  $itersnum = $varinumbers[$countcase]{$varinumber}; say "\$itersnum: $itersnum"; 
 		#say "dump(\@varinumbers), " . dump(@varinumbers); #say "dumpBEFORE(\@miditers), " . dump(@miditers);
-	
+		
+		my ( $sweepz_ref, $sourcesweeps_ref ) = readsweeps( @sweeps );
+		my @sweepz = @$sweepz_ref;
+		@sourcesweeps = @$sourcesweeps_ref; #my @sourcesweeps =...  #say "\@sourcesweeps : " . dump( @sourcesweeps );
+		if ( @sweepz)
+		{
+			@sweeps = @sweepz;
+		} #say "\@sweeps : " . dump( @sweeps );
+		
 		calcoverlaps( @sweeps ); # PRODUCES @calcoverlaps WHICH IS global. ZZZ
 		#say $tee "VARINUMBERS: " . dump ( @varinumbers );
 		@mediumiters = calcmediumiters( @varinumbers ); #say $tee "(\@mediumitems): " . dump(@mediumiters); # globsALS. ZZZ
